# encoding: utf-8

from auf.django.references import models as ref
from django.db import models


class Element(models.Model):
    code = models.CharField(max_length=72, primary_key=True)
    timestamp = models.BigIntegerField()
    nom = models.CharField(max_length=36)

    class Meta:
        abstract = True
        ordering = ['code']

    def __unicode__(self):
        return self.code


class PCG(Element):

    class Meta:
        db_table = 'coda_pcg'


class TiersOperation(Element):
    etablissement = models.OneToOneField(ref.Etablissement, related_name='coda_tiers_operation',
                                         blank=True, null=True)

    class Meta:
        db_table = 'coda_tiersoperation'


class ProjetPoste(Element):

    class Meta:
        db_table = 'coda_projetposte'


class Ecriture(models.Model):
    id = models.CharField(max_length=25, primary_key=True)
    code = models.CharField(max_length=12)
    numero = models.CharField(max_length=12)
    timestamp = models.BigIntegerField()
    periode = models.IntegerField()
    annee = models.IntegerField()
    date = models.DateField()

    class Meta:
        db_table = 'coda_ecriture'
        ordering = ['id']


class Ligne(models.Model):
    DEBIT_CREDIT_CHOICES = (
        ('D', 'Débit'),
        ('C', 'Crédit'),
    )
    ETAT_PAIEMENT_CHOICES = (
        ('D', 'Disponible'),
        ('A', 'Attente'),
        ('X', 'Fermé (non-lettrable)'),
        ('P', 'Payé'),
        ('O', 'Proposé'),
        ('F', 'Effet en cours'),
        ('Y', 'Effet payé'),
        ('J', 'Effet en attente'),
    )

    id = models.CharField(max_length=36, primary_key=True)
    ecriture = models.ForeignKey(Ecriture, related_name='lignes')
    numero = models.IntegerField()
    timestamp = models.BigIntegerField()
    pcg = models.ForeignKey(PCG, related_name='lignes')
    tiers_operation = models.ForeignKey(TiersOperation, related_name='lignes', blank=True, null=True)
    projet_poste = models.ForeignKey(ProjetPoste, related_name='lignes', blank=True, null=True)
    description = models.CharField(max_length=36)
    montant_eur = models.DecimalField(max_digits=17, decimal_places=2)
    debit_credit = models.CharField(max_length=1, choices=DEBIT_CREDIT_CHOICES)
    numero_facture = models.CharField(max_length=32)
    numero_avoir = models.CharField(max_length=32)
    implantation = models.CharField(max_length=32)
    salarie = models.CharField(max_length=32)
    numero_cheque = models.CharField(max_length=32)
    etat_paiement = models.CharField(max_length=1, choices=ETAT_PAIEMENT_CHOICES)

    class Meta:
        db_table = 'coda_ligne'
        ordering = ['id']
